parse_limit

Function parse_limit 

fn parse_limit(raw: Option<&&str>) -> Result<usize, String>
Parses the message limit argument.

Arguments

  • raw - An Option containing the raw string value of the limit.

Returns

A Result containing the parsed usize limit or an error message.